resolve_lane

Function resolve_lane 

pub fn resolve_lane(
    opts: &mut TempoOpts,
    root: &Path,
) -> Result<Option<ResolvedLane>>
Resolves opts.lane against a lanes file and writes the resulting nonce_key to opts.nonce_key. Returns the resolved lane (or None if no --tempo.lane was set).

root is the project root used to locate the default lanes file (<root>/tempo.lanes.toml) when --tempo.lanes-file was not provided.