CommandUtils

Trait CommandUtils 

pub trait CommandUtils {
    // Required methods
    fn exec(&mut self) -> Result<Output>;
    fn get_stdout_lossy(&mut self) -> Result<String>;
}
Useful extensions to std::process::Command.

Required Methods

fn exec(&mut self) -> Result<Output>

Returns the command’s output if execution is successful, otherwise, throws an error.

fn get_stdout_lossy(&mut self) -> Result<String>

Returns the command’s stdout if execution is successful, otherwise, throws an error.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl CommandUtils for Command

Source

fn exec(&mut self) -> Result<Output>

Source

fn get_stdout_lossy(&mut self) -> Result<String>

Implementors